@@ -11,7 +11,7 @@
 // but WITHOUT ANY WARRANTY; without even the implied warranty of
 // MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 // GNU General Public License for more details.
-// 
+//
 // You should have received a copy of the GNU General Public License
 // along with this program; if not, write to the Free Software
 // Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.
@@ -20,28 +20,29 @@
 
 using System;
 using LongoMatch.DB;
+using LongoMatch.Common;
 
 namespace LongoMatch.Gui.Dialog
 {
-	
+
 	[System.ComponentModel.Category("LongoMatch")]
 	[System.ComponentModel.ToolboxItem(false)]
 	public partial class NewProjectDialog : Gtk.Dialog
 	{
-		
+
 		public NewProjectDialog()
 		{
-			this.Build();			
+			this.Build();
 			fdwidget.Clear();
 		}
-		
-		public LongoMatch.Gui.Component.UseType Use{
+
+		public ProjectType Use {
 			set {
-				this.fdwidget.Use = value;				
+				this.fdwidget.Use = value;
 			}
 		}
-		
-		public Project GetProject(){
+
+		public Project GetProject() {
 			return this.fdwidget.GetProject();
 		}
 	}
