@@ -11,7 +11,7 @@
 // but WITHOUT ANY WARRANTY; without even the implied warranty of
 // MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 // GNU General Public License for more details.
-// 
+//
 // You should have received a copy of the GNU General Public License
 // along with this program; if not, write to the Free Software
 //Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.
@@ -31,9 +31,9 @@ using LongoMatch.TimeNodes;
 using System.Runtime.InteropServices;
 
 namespace LongoMatch
-	
+
 {
-	
+
 	class MainClass
 	{
 		private static DataBase db;
@@ -41,121 +41,121 @@ namespace LongoMatch
 		private static string homeDirectory;
 		private static string configDirectory;
 		private const string WIN32_CONFIG_FILE = "longomatch.conf";
-		
-		public static void Main (string[] args)
-		{		
+
+		public static void Main(string[] args)
+		{
 			//Configuramos el directorio base de la ejecucuión y el directorio HOME
 			baseDirectory = System.IO.Path.Combine(System.AppDomain.CurrentDomain.BaseDirectory,"../../");
 			homeDirectory = System.Environment.GetFolderPath(Environment.SpecialFolder.Personal);
 			configDirectory = System.IO.Path.Combine(homeDirectory,".longomatch");
 			homeDirectory = System.IO.Path.Combine(homeDirectory,"LongoMatch");
-			
-			if (Environment.OSVersion.Platform == PlatformID.Win32NT){				
+
+			if (Environment.OSVersion.Platform == PlatformID.Win32NT) {
 				SetUpWin32Config();
 			}
-					
+
 			//Iniciamos la internalización
-			Catalog.Init("longomatch",RelativeToPrefix("share/locale"));			
-								
+			Catalog.Init("longomatch",RelativeToPrefix("share/locale"));
+
 			//Iniciamos la aplicación
-			Application.Init ();
-			
+			Application.Init();
+
 			GLib.ExceptionManager.UnhandledException += new GLib.UnhandledExceptionHandler(OnException);
-				
+
 			LongoMatch.Video.Player.GstPlayer.InitBackend("");
-							
+
 			//Comprobamos los archivos de inicio
 			CheckDirs();
-			CheckFiles();			
-			
+			CheckFiles();
+
 			//Iniciamos la base de datos
-			db = new DataBase(Path.Combine(DBDir(),"longomatch.db"));			
-			
+			db = new DataBase(Path.Combine(DBDir(),"longomatch.db"));
+
 			//Check for previous database
 			CheckOldFiles();
-			
-			try {
-				MainWindow win = new MainWindow ();
-				win.Show ();			
-				Application.Run ();
-			}catch (Exception ex){
-				ProcessExecutionError(ex);				
-			}			
-		}
-		
-		public static string RelativeToPrefix(string relativePath){
-			return System.IO.Path.Combine (baseDirectory, relativePath);
-		}
-		
-		public static string HomeDir(){
-				return homeDirectory;	
-		}		
 
-		public static string PlayListDir(){
-			return System.IO.Path.Combine (homeDirectory, "playlists");
+			try {
+				MainWindow win = new MainWindow();
+				win.Show();
+				Application.Run();
+			} catch (Exception ex) {
+				ProcessExecutionError(ex);
+			}
 		}
-		
-		public static string SnapshotsDir(){
-			return System.IO.Path.Combine (homeDirectory, "snapshots");
+
+		public static string RelativeToPrefix(string relativePath) {
+			return System.IO.Path.Combine(baseDirectory, relativePath);
 		}
-		
-		public static string TemplatesDir(){
-			return System.IO.Path.Combine (configDirectory, "templates");
-		}		
-				
-		public static string VideosDir(){
-			return System.IO.Path.Combine (homeDirectory, "videos");
+
+		public static string HomeDir() {
+			return homeDirectory;
 		}
-		
-		public static string TempVideosDir(){
-			return System.IO.Path.Combine (configDirectory, "temp");
+
+		public static string PlayListDir() {
+			return System.IO.Path.Combine(homeDirectory, "playlists");
 		}
-		
-		public static string ImagesDir(){			
-			return RelativeToPrefix("share/longomatch/images");		
+
+		public static string SnapshotsDir() {
+			return System.IO.Path.Combine(homeDirectory, "snapshots");
 		}
-		
-		public static string DBDir(){
-			return System.IO.Path.Combine (configDirectory, "db");
-		}	
-		
-		public static void CheckDirs(){
+
+		public static string TemplatesDir() {
+			return System.IO.Path.Combine(configDirectory, "templates");
+		}
+
+		public static string VideosDir() {
+			return System.IO.Path.Combine(homeDirectory, "videos");
+		}
+
+		public static string TempVideosDir() {
+			return System.IO.Path.Combine(configDirectory, "temp");
+		}
+
+		public static string ImagesDir() {
+			return RelativeToPrefix("share/longomatch/images");
+		}
+
+		public static string DBDir() {
+			return System.IO.Path.Combine(configDirectory, "db");
+		}
+
+		public static void CheckDirs() {
 			if (!System.IO.Directory.Exists(homeDirectory))
-			    System.IO.Directory.CreateDirectory(homeDirectory);
+				System.IO.Directory.CreateDirectory(homeDirectory);
 			if (!System.IO.Directory.Exists(TemplatesDir()))
-			    System.IO.Directory.CreateDirectory(TemplatesDir());
+				System.IO.Directory.CreateDirectory(TemplatesDir());
 			if (!System.IO.Directory.Exists(SnapshotsDir()))
-			    System.IO.Directory.CreateDirectory(SnapshotsDir());
+				System.IO.Directory.CreateDirectory(SnapshotsDir());
 			if (!System.IO.Directory.Exists(PlayListDir()))
-			    System.IO.Directory.CreateDirectory(PlayListDir());
+				System.IO.Directory.CreateDirectory(PlayListDir());
 			if (!System.IO.Directory.Exists(DBDir()))
-			    System.IO.Directory.CreateDirectory(DBDir());
+				System.IO.Directory.CreateDirectory(DBDir());
 			if (!System.IO.Directory.Exists(VideosDir()))
-			    System.IO.Directory.CreateDirectory(VideosDir());
+				System.IO.Directory.CreateDirectory(VideosDir());
 			if (!System.IO.Directory.Exists(TempVideosDir()))
-			    System.IO.Directory.CreateDirectory(TempVideosDir());			  
+				System.IO.Directory.CreateDirectory(TempVideosDir());
 		}
-		
-		public static void CheckFiles(){			
+
+		public static void CheckFiles() {
 			string fConfig;
 			fConfig = System.IO.Path.Combine(TemplatesDir(),"default.sct");
-			if (!System.IO.File.Exists(fConfig)){
-			    SectionsWriter.CreateNewTemplate("default.sct");
+			if (!System.IO.File.Exists(fConfig)) {
+				SectionsWriter.CreateNewTemplate("default.sct");
 			}
-			
+
 			fConfig = System.IO.Path.Combine(TemplatesDir(),"default.tem");
-			if (!System.IO.File.Exists(fConfig)){
+			if (!System.IO.File.Exists(fConfig)) {
 				TeamTemplate tt = new TeamTemplate();
 				tt.CreateDefaultTemplate(20);
-				tt.Save(fConfig);					
-			}			
+				tt.Save(fConfig);
+			}
 		}
-		
-		public static void CheckOldFiles(){
-			string oldDBFile= System.IO.Path.Combine (homeDirectory, "db/db.yap");
+
+		public static void CheckOldFiles() {
+			string oldDBFile= System.IO.Path.Combine(homeDirectory, "db/db.yap");
 			//We supose that if the conversion as already be done successfully,
 			//old DB file has been renamed to db.yap.bak
-			if (File.Exists(oldDBFile)){
+			if (File.Exists(oldDBFile)) {
 				MessageDialog md = new MessageDialog(null,
 				                                     DialogFlags.Modal,
 				                                     MessageType.Question,
@@ -163,26 +163,28 @@ namespace LongoMatch
 				                                     Catalog.GetString("Some elements from the previous version (database, templates and/or playlists) have been found.")+"\n"+
 				                                     Catalog.GetString("Do you want to import them?"));
 				md.Icon=Stetic.IconLoader.LoadIcon(md, "longomatch", Gtk.IconSize.Dialog, 48);
-				if(md.Run()==(int)ResponseType.Yes){
+				if (md.Run()==(int)ResponseType.Yes) {
 					md.Destroy();
 					Migrator migrator = new Migrator(homeDirectory);
 					migrator.Run();
 					migrator.Destroy();
 				}
-				else 
+				else
 					md.Destroy();
 			}
 		}
-		
-		public static DataBase DB{
-			get { return db;}
+
+		public static DataBase DB {
+			get {
+				return db;
+			}
 		}
-		
-		private static void SetUpWin32Config(){
+
+		private static void SetUpWin32Config() {
 			Environment.SetEnvironmentVariable("GST_PLUGIN_PATH",RelativeToPrefix("lib\\gstreamer-0.10"));
 			baseDirectory = System.IO.Path.Combine(System.AppDomain.CurrentDomain.BaseDirectory,"../");
 
-			try{
+			try {
 				StreamReader reader = new StreamReader(System.IO.Path.Combine(homeDirectory,WIN32_CONFIG_FILE));
 				homeDirectory = reader.ReadLine();
 				configDirectory = homeDirectory;
@@ -196,41 +198,41 @@ namespace LongoMatch
 				//in the installation path. Use the default homeDirectory
 				//and let the user change it by hand
 				configDirectory=homeDirectory;
-			}		
-		}		
-			
-		private static void OnException(GLib.UnhandledExceptionArgs args){
-			ProcessExecutionError((Exception)args.ExceptionObject);				
+			}
 		}
-		
-		private static void ProcessExecutionError(Exception ex){
+
+		private static void OnException(GLib.UnhandledExceptionArgs args) {
+			ProcessExecutionError((Exception)args.ExceptionObject);
+		}
+
+		private static void ProcessExecutionError(Exception ex) {
 			//Try to save the database before exiting
-			 if (MainWindow.OpenedProject() != null)
+			if (MainWindow.OpenedProject() != null)
 				DB.UpdateProject(MainWindow.OpenedProject());
 			string logFile ="LongoMatch-" + DateTime.Now +".log";
 			string message;
-			
+
 			logFile = logFile.Replace("/","-");
 			logFile = logFile.Replace(" ","-");
 			logFile = logFile.Replace(":","-");
-			logFile = System.IO.Path.Combine(HomeDir(),logFile); 
-			
+			logFile = System.IO.Path.Combine(HomeDir(),logFile);
+
 			if (ex.InnerException != null)
 				message = String.Format("{0}\n{1}\n{2}\n{3}\n{4}",ex.Message,ex.InnerException.Message,ex.Source,ex.StackTrace,ex.InnerException.StackTrace);
 			else
 				message = String.Format("{0}\n{1}\n{2}",ex.Message,ex.Source,ex.StackTrace);
 
-			using (StreamWriter s = new StreamWriter(logFile)){
+			using(StreamWriter s = new StreamWriter(logFile)) {
 				s.WriteLine(message);
 				s.WriteLine("\n\n\nStackTrace:");
 				s.WriteLine(System.Environment.StackTrace);
-			}	 
+			}
 			//TODO Add bug reports link
-			MessagePopup.PopupMessage(null, MessageType.Error, 
+			MessagePopup.PopupMessage(null, MessageType.Error,
 			                          Catalog.GetString("The application has finished with an unexpected error.")+"\n"+
 			                          Catalog.GetString("A log has been saved at: ")+logFile+ "\n"+
 			                          Catalog.GetString("Please, fill a bug report "));
-			
+
 			Application.Quit();
 		}
 	}
